openBluetoothSettings static method
Opens the system Bluetooth settings screen.
Returns true if the settings screen was opened successfully.
Returns false if the action failed or is not supported.
Implementation
static Future<bool?> openBluetoothSettings() =>
_invoke<bool>('openBluetoothSettings');